
from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ntnx_dataprotection_py_client.api.protected_resources_api import ProtectedResourcesApi
from ntnx_dataprotection_py_client.api.recovery_points_api import RecoveryPointsApi



# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
import ntnx_dataprotection_py_client.models
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.common.BaseVmRecoveryPointapplication_consistent_properties import BaseVmRecoveryPointapplication_consistent_properties  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseRecoveryPoint import BaseRecoveryPoint  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint import DiskRecoveryPoint  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointStatus import RecoveryPointStatus  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointType import RecoveryPointType  # noqa: F401,E501

class BaseVmRecoveryPoint(BaseRecoveryPoint):

    """A model that represents common properties of a VM Recovery point resources

    :param consistency_group_ext_id: (:attr:`consistency_group_ext_id`) External identifier of the Consistency group which the VM was part of at the time of recovery point creation.
    :type consistency_group_ext_id: 
    
    
    :param disk_recovery_points: (:attr:`disk_recovery_points`) 
    :type disk_recovery_points: 
    
    
    :param vm_ext_id: (:attr:`vm_ext_id`) VM external identifier which is captured as a part of this recovery point.
    :type vm_ext_id: 
    
    
    :param vm_categories: (:attr:`vm_categories`) Category key-value pairs associated with the VM at the time of recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' is displayed as 'dept/hr'.
    :type vm_categories: 
    
    
    :param application_consistent_properties: (:attr:`application_consistent_properties`) User-defined application-consistent properties for the recovery point.
    :type application_consistent_properties: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'consistency_group_ext_id': 'str',
        'disk_recovery_points': 'list[dataprotection.v4.common.DiskRecoveryPoint]',
        'vm_ext_id': 'str',
        'vm_categories': 'list[str]',
        'application_consistent_properties': 'OneOfdataprotection.v4.common.BaseVmRecoveryPointapplication_consistent_properties',
        'location_agnostic_id': 'str',
        'name': 'str',
        'creation_time': 'datetime',
        'expiration_time': 'datetime',
        'status': 'dataprotection.v4.common.RecoveryPointStatus',
        'recovery_point_type': 'dataprotection.v4.common.RecoveryPointType',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'consistency_group_ext_id': 'consistencyGroupExtId',
        'disk_recovery_points': 'diskRecoveryPoints',
        'vm_ext_id': 'vmExtId',
        'vm_categories': 'vmCategories',
        'application_consistent_properties': 'applicationConsistentProperties',
        'location_agnostic_id': 'locationAgnosticId',
        'name': 'name',
        'creation_time': 'creationTime',
        'expiration_time': 'expirationTime',
        'status': 'status',
        'recovery_point_type': 'recoveryPointType',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, consistency_group_ext_id=None, disk_recovery_points=None, vm_ext_id=None, vm_categories=None, application_consistent_properties=None, location_agnostic_id=None, name=None, creation_time=None, expiration_time=None, status=None, recovery_point_type=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        BaseRecoveryPoint.__init__(self, location_agnostic_id, name, creation_time, expiration_time, status, recovery_point_type, ext_id, links, tenant_id, *args, **kwargs)
        self.__consistency_group_ext_id = None
        self.__disk_recovery_points = None
        self.__vm_ext_id = None
        self.__vm_categories = None
        self.__application_consistent_properties = None
        self.discriminator = None
        if consistency_group_ext_id is not None:
            self.__consistency_group_ext_id = consistency_group_ext_id
        if disk_recovery_points is not None:
            self.__disk_recovery_points = disk_recovery_points
        if vm_ext_id is not None:
            self.__vm_ext_id = vm_ext_id
        if vm_categories is not None:
            self.__vm_categories = vm_categories
        if application_consistent_properties is not None:
            self.__application_consistent_properties = application_consistent_properties

    def _initialize_object_type(self):
        return 'dataprotection.v4.common.BaseVmRecoveryPoint'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def consistency_group_ext_id(self):
        """
        External identifier of the Consistency group which the VM was part of at the time of recovery point creation.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__consistency_group_ext_id

    @consistency_group_ext_id.setter
    def consistency_group_ext_id(self, consistency_group_ext_id):
        if consistency_group_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', consistency_group_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `consistency_group_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__consistency_group_ext_id = consistency_group_ext_id

    @property
    def disk_recovery_points(self):
        """
        

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint` ]
        """  # noqa: E501
        return self.__disk_recovery_points

    @disk_recovery_points.setter
    def disk_recovery_points(self, disk_recovery_points):

        self.__disk_recovery_points = disk_recovery_points

    @property
    def vm_ext_id(self):
        """
        VM external identifier which is captured as a part of this recovery point.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__vm_ext_id

    @vm_ext_id.setter
    def vm_ext_id(self, vm_ext_id):
        if vm_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', vm_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `vm_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__vm_ext_id = vm_ext_id

    @property
    def vm_categories(self):
        """
        Category key-value pairs associated with the VM at the time of recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' is displayed as 'dept/hr'.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__vm_categories

    @vm_categories.setter
    def vm_categories(self, vm_categories):

        self.__vm_categories = vm_categories

    @property
    def application_consistent_properties(self):
        """
        User-defined application-consistent properties for the recovery point.

        :type:
                :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.common.VssProperties`
        """  # noqa: E501
        return self.__application_consistent_properties

    @application_consistent_properties.setter
    def application_consistent_properties(self, application_consistent_properties):

        self.__application_consistent_properties = application_consistent_properties

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if attr_type.startswith('OneOf'):
                type = getattr(ntnx_dataprotection_py_client.models, attr_type.split('.')[-1])
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(BaseVmRecoveryPoint, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseVmRecoveryPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BackupType import BackupType  # noqa: F401,E501

class VssProperties(object):

    """For Windows VMs/agents, application-consistent recovery points are selected using the Windows-specific Volume Shadow Copy Service (VSS). The enclosed properties, also called VSS properties, are used by the Windows platform to decide the type of application-consistent recovery points to consider.

    :param backup_type: (:attr:`backup_type`) 
    :type backup_type: required
    
    
    :param should_include_writers: (:attr:`should_include_writers`) Indicates whether the given set of VSS writers' UUIDs should be included or excluded from the application consistent recovery point. By default, the value is set to false, indicating that all listed VSS writers' UUIDs will be excluded. (**Default** False)
    :type should_include_writers: 
    
    
    :param writers: (:attr:`writers`) List of VSS writer UUIDs that are used in an application consistent recovery point. The default values are the system and the registry writer UUIDs.
    :type writers: 
    
    
    :param should_store_vss_metadata: (:attr:`should_store_vss_metadata`) Indicates whether to store the VSS metadata if the user is interested in application-specific backup/restore. The VSS metadata consists of VSS writers and requester metadata details. These are compressed into a cabinet file(.cab file) during a VSS backup operation. This cabinet file must be saved to the backup media during a backup operation, as it is required during the restore operation. (**Default** False)
    :type should_store_vss_metadata: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'backup_type': 'dataprotection.v4.common.BackupType',
        'should_include_writers': 'bool',
        'writers': 'list[str]',
        'should_store_vss_metadata': 'bool',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'backup_type': 'backupType',
        'should_include_writers': 'shouldIncludeWriters',
        'writers': 'writers',
        'should_store_vss_metadata': 'shouldStoreVssMetadata',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, backup_type=None, should_include_writers=False, writers=None, should_store_vss_metadata=False, *args, **kwargs):  # noqa: E501
        self.__backup_type = None
        self.__should_include_writers = None
        self.__writers = None
        self.__should_store_vss_metadata = None
        self.discriminator = None
        self.__backup_type = backup_type
        if should_include_writers is not None:
            self.__should_include_writers = should_include_writers
        if writers is not None:
            self.__writers = writers
        if should_store_vss_metadata is not None:
            self.__should_store_vss_metadata = should_store_vss_metadata
        # populate hidden vars if not empty
        self._populate_hidden_vars(kwargs)

    def _initialize_object_type(self):
        return 'dataprotection.v4.common.VssProperties'

    def _initialize_object_version(self):
        return 'v4.r0'

    def _populate_hidden_vars(self, kwargs):
        if "_reserved" in kwargs and kwargs["_reserved"] is not None:
            self.__dollar_reserved = kwargs["_reserved"]
        elif hasattr(self, "attribute_map") and "_reserved" in self.attribute_map and self.attribute_map["_reserved"] in kwargs and kwargs[self.attribute_map["_reserved"]] is not None:
            self.__dollar_reserved = kwargs[self.attribute_map["_reserved"]]
        else :
            self.__dollar_reserved = {"$fv": self._initialize_object_version()}
        if "_unknown_fields" in kwargs and kwargs["_unknown_fields"] is not None:
            self.__dollar_unknown_fields = kwargs["_unknown_fields"]
        elif hasattr(self, "attribute_map") and "_unknown_fields" in self.attribute_map and self.attribute_map["_unknown_fields"] in kwargs and kwargs[self.attribute_map["_unknown_fields"]] is not None:
            self.__dollar_unknown_fields = kwargs[self.attribute_map["_unknown_fields"]]
        else :
            self.__dollar_unknown_fields = {}
        if "_object_type" in kwargs and kwargs["_object_type"] is not None:
            self.__dollar_object_type = kwargs["_object_type"]
        elif hasattr(self, "attribute_map") and "_object_type" in self.attribute_map and self.attribute_map["_object_type"] in kwargs and kwargs[self.attribute_map["_object_type"]] is not None:
            self.__dollar_object_type = kwargs[self.attribute_map["_object_type"]]
        else:
            self.__dollar_object_type = self._initialize_object_type()

    def get_object_type(self):
        return self.__dollar_object_type

    def get_reserved(self):
        return self.__dollar_reserved

    def get_unknown_fields(self):
        return self.__dollar_unknown_fields

    @property
    def backup_type(self):
        """
        

        :type:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.common.BackupType`
        """  # noqa: E501
        return self.__backup_type

    @backup_type.setter
    def backup_type(self, backup_type):
        if backup_type is None:
            raise ValueError("Invalid value for `backup_type`, must not be `None`")  # noqa: E501

        self.__backup_type = backup_type

    @property
    def should_include_writers(self):
        """
        Indicates whether the given set of VSS writers' UUIDs should be included or excluded from the application consistent recovery point. By default, the value is set to false, indicating that all listed VSS writers' UUIDs will be excluded.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__should_include_writers

    @should_include_writers.setter
    def should_include_writers(self, should_include_writers):

        self.__should_include_writers = should_include_writers

    @property
    def writers(self):
        """
        List of VSS writer UUIDs that are used in an application consistent recovery point. The default values are the system and the registry writer UUIDs.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__writers

    @writers.setter
    def writers(self, writers):

        self.__writers = writers

    @property
    def should_store_vss_metadata(self):
        """
        Indicates whether to store the VSS metadata if the user is interested in application-specific backup/restore. The VSS metadata consists of VSS writers and requester metadata details. These are compressed into a cabinet file(.cab file) during a VSS backup operation. This cabinet file must be saved to the backup media during a backup operation, as it is required during the restore operation.

        :type:
                :class:`~bool`
        """  # noqa: E501
        return self.__should_store_vss_metadata

    @should_store_vss_metadata.setter
    def should_store_vss_metadata(self, should_store_vss_metadata):

        self.__should_store_vss_metadata = should_store_vss_metadata

    @property
    def _reserved(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_reserved

    @property
    def _object_type(self):
        """
        

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__dollar_object_type

    @property
    def _unknown_fields(self):
        """
        

        :type:
            dict(str, :class:`~object`)
        """  # noqa: E501
        return self.__dollar_unknown_fields

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VssProperties, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VssProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint import DiskRecoveryPoint  # noqa: F401,E501

class VolumeGroupRecoveryPoint(ExternalizableAbstractModel):

    """A model that represents volume group recovery point properties.

    :param consistency_group_ext_id: (:attr:`consistency_group_ext_id`) External identifier of the Consistency group which the entity was part of at the time of recovery point creation.
    :type consistency_group_ext_id: 
    
    
    :param location_agnostic_id: (:attr:`location_agnostic_id`) Location agnostic identifier of the recovery point. This identifier is used to identify the same instances of a recovery point across different sites.
    :type location_agnostic_id: 
    
    
    :param volume_group_ext_id: (:attr:`volume_group_ext_id`) Volume Group external identifier which is captured as part of this recovery point.
    :type volume_group_ext_id: required
    
    
    :param volume_group_categories: (:attr:`volume_group_categories`) Category key-value pairs associated with the volume group at the time of recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.
    :type volume_group_categories: 
    
    
    :param disk_recovery_points: (:attr:`disk_recovery_points`) 
    :type disk_recovery_points: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'consistency_group_ext_id': 'str',
        'location_agnostic_id': 'str',
        'volume_group_ext_id': 'str',
        'volume_group_categories': 'list[str]',
        'disk_recovery_points': 'list[dataprotection.v4.common.DiskRecoveryPoint]',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'consistency_group_ext_id': 'consistencyGroupExtId',
        'location_agnostic_id': 'locationAgnosticId',
        'volume_group_ext_id': 'volumeGroupExtId',
        'volume_group_categories': 'volumeGroupCategories',
        'disk_recovery_points': 'diskRecoveryPoints',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, consistency_group_ext_id=None, location_agnostic_id=None, volume_group_ext_id=None, volume_group_categories=None, disk_recovery_points=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__consistency_group_ext_id = None
        self.__location_agnostic_id = None
        self.__volume_group_ext_id = None
        self.__volume_group_categories = None
        self.__disk_recovery_points = None
        self.discriminator = None
        if consistency_group_ext_id is not None:
            self.__consistency_group_ext_id = consistency_group_ext_id
        if location_agnostic_id is not None:
            self.__location_agnostic_id = location_agnostic_id
        self.__volume_group_ext_id = volume_group_ext_id
        if volume_group_categories is not None:
            self.__volume_group_categories = volume_group_categories
        if disk_recovery_points is not None:
            self.__disk_recovery_points = disk_recovery_points

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.VolumeGroupRecoveryPoint'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def consistency_group_ext_id(self):
        """
        External identifier of the Consistency group which the entity was part of at the time of recovery point creation.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__consistency_group_ext_id

    @consistency_group_ext_id.setter
    def consistency_group_ext_id(self, consistency_group_ext_id):
        if consistency_group_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', consistency_group_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `consistency_group_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__consistency_group_ext_id = consistency_group_ext_id

    @property
    def location_agnostic_id(self):
        """
        Location agnostic identifier of the recovery point. This identifier is used to identify the same instances of a recovery point across different sites.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__location_agnostic_id

    @location_agnostic_id.setter
    def location_agnostic_id(self, location_agnostic_id):
        if location_agnostic_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', location_agnostic_id):  # noqa: E501
            raise ValueError(r"Invalid value for `location_agnostic_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__location_agnostic_id = location_agnostic_id

    @property
    def volume_group_ext_id(self):
        """
        Volume Group external identifier which is captured as part of this recovery point.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__volume_group_ext_id

    @volume_group_ext_id.setter
    def volume_group_ext_id(self, volume_group_ext_id):
        if volume_group_ext_id is None:
            raise ValueError("Invalid value for `volume_group_ext_id`, must not be `None`")  # noqa: E501
        if volume_group_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', volume_group_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `volume_group_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__volume_group_ext_id = volume_group_ext_id

    @property
    def volume_group_categories(self):
        """
        Category key-value pairs associated with the volume group at the time of recovery point creation. The category key and value are separated by '/'. For example, a category with key 'dept' and value 'hr' will be represented as 'dept/hr'.

        :type:
            list[ :class:`~str` ]
        """  # noqa: E501
        return self.__volume_group_categories

    @volume_group_categories.setter
    def volume_group_categories(self, volume_group_categories):

        self.__volume_group_categories = volume_group_categories

    @property
    def disk_recovery_points(self):
        """
        

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint` ]
        """  # noqa: E501
        return self.__disk_recovery_points

    @disk_recovery_points.setter
    def disk_recovery_points(self, disk_recovery_points):

        self.__disk_recovery_points = disk_recovery_points

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(VolumeGroupRecoveryPoint, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeGroupRecoveryPoint):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




# coding: utf-8

# flake8: noqa

"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

# import models into model package
from ntnx_dataprotection_py_client.models.OneOfcommon.v1.config.KVPairvalue import KVPairvalue
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.common.BaseVmRecoveryPointapplication_consistent_properties import BaseVmRecoveryPointapplication_consistent_properties
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ClusterInfoApiResponsedata import ClusterInfoApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateConsistencyGroupApiResponsedata import CreateConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.CreateRecoveryPointApiResponsedata import CreateRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteConsistencyGroupApiResponsedata import DeleteConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.DeleteRecoveryPointApiResponsedata import DeleteRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.GetProtectedResourceApiResponsedata import GetProtectedResourceApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.GetRecoveryPointApiResponsedata import GetRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.GetVmRecoveryPointApiResponsedata import GetVmRecoveryPointApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ListRecoveryPointsApiResponsedata import ListRecoveryPointsApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.MigrateConsistencyGroupApiResponsedata import MigrateConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourcePromoteApiResponsedata import ProtectedResourcePromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.ProtectedResourceRestoreApiResponsedata import ProtectedResourceRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointReplicateApiResponsedata import RecoveryPointReplicateApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRepositoryProjectionobject_storage_reference import RecoveryPointRepositoryProjectionobject_storage_reference
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRepositoryobject_storage_reference import RecoveryPointRepositoryobject_storage_reference
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.RecoveryPointRestoreApiResponsedata import RecoveryPointRestoreApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.SynchronousReplicaPromoteApiResponsedata import SynchronousReplicaPromoteApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.UpdateConsistencyGroupApiResponsedata import UpdateConsistencyGroupApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponsedata import UpdateRecoveryPointExpirationTimeApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.config.VmRecoveryPointapplication_consistent_properties import VmRecoveryPointapplication_consistent_properties
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ChangedVmRegionsApiResponsedata import ChangedVmRegionsApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ChangedVolumeGroupRegionsApiResponsedata import ChangedVolumeGroupRegionsApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ClusterDiscoverSpecspec import ClusterDiscoverSpecspec
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ComputeChangedRegionsClusterDiscoverSpecdisk_recovery_point import ComputeChangedRegionsClusterDiscoverSpecdisk_recovery_point
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.ComputeChangedRegionsClusterDiscoverSpecreference_disk_recovery_point import ComputeChangedRegionsClusterDiscoverSpecreference_disk_recovery_point
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.content.GetVssMetadataApiResponsedata import GetVssMetadataApiResponsedata
from ntnx_dataprotection_py_client.models.OneOfdataprotection.v4.error.ErrorResponseerror import ErrorResponseerror
from ntnx_dataprotection_py_client.models.common.v1.config.Flag import Flag
from ntnx_dataprotection_py_client.models.common.v1.config.IPAddress import IPAddress
from ntnx_dataprotection_py_client.models.common.v1.config.IPv4Address import IPv4Address
from ntnx_dataprotection_py_client.models.common.v1.config.IPv6Address import IPv6Address
from ntnx_dataprotection_py_client.models.common.v1.config.KVPair import KVPair
from ntnx_dataprotection_py_client.models.common.v1.config.MapOfStringWrapper import MapOfStringWrapper
from ntnx_dataprotection_py_client.models.common.v1.config.Message import Message
from ntnx_dataprotection_py_client.models.common.v1.config.MessageSeverity import MessageSeverity
from ntnx_dataprotection_py_client.models.common.v1.config.TenantAwareModel import TenantAwareModel
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink
from ntnx_dataprotection_py_client.models.common.v1.response.ApiResponseMetadata import ApiResponseMetadata
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BackupType import BackupType
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseRecoveryPoint import BaseRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.BaseVmRecoveryPoint import BaseVmRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.ClusterInfo import ClusterInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.DiskRecoveryPoint import DiskRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointStatus import RecoveryPointStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.RecoveryPointType import RecoveryPointType
from ntnx_dataprotection_py_client.models.dataprotection.v4.common.VssProperties import VssProperties
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AhvVmOverrideSpec import AhvVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AmazonS3Bucket import AmazonS3Bucket
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.AzureBlobStorageContainer import AzureBlobStorageContainer
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ClusterInfoApiResponse import ClusterInfoApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroup import ConsistencyGroup
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember import ConsistencyGroupMember
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMemberType import ConsistencyGroupMemberType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMigrationSpec import ConsistencyGroupMigrationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupProjection import ConsistencyGroupProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateConsistencyGroupApiResponse import CreateConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateRecoveryPointApiResponse import CreateRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DataProtectionSiteReference import DataProtectionSiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteConsistencyGroupApiResponse import DeleteConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteRecoveryPointApiResponse import DeleteRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.EsxiVmOverrideSpec import EsxiVmOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ExpirationTimeSpec import ExpirationTimeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetProtectedResourceApiResponse import GetProtectedResourceApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetRecoveryPointApiResponse import GetRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetVmRecoveryPointApiResponse import GetVmRecoveryPointApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostReference import HostReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.HostType import HostType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.IpAddress import IpAddress
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ListRecoveryPointsApiResponse import ListRecoveryPointsApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.LocationReference import LocationReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.MigrateConsistencyGroupApiResponse import MigrateConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.NutanixObjectsBucket import NutanixObjectsBucket
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ObjectStorageType import ObjectStorageType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedEntityType import ProtectedEntityType
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResource import ProtectedResource
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourcePromoteApiResponse import ProtectedResourcePromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceReplicationStatus import ProtectedResourceReplicationStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreApiResponse import ProtectedResourceRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ProtectedResourceRestoreSpec import ProtectedResourceRestoreSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryInfo import RecoveryInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPoint import RecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointProjection import RecoveryPointProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicateApiResponse import RecoveryPointReplicateApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicationSpec import RecoveryPointReplicationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRepository import RecoveryPointRepository
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRepositoryProjection import RecoveryPointRepositoryProjection
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestorationSpec import RecoveryPointRestorationSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestoreApiResponse import RecoveryPointRestoreApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ReplicationState import ReplicationState
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.RestorableTimeRange import RestorableTimeRange
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteProtectionInfo import SiteProtectionInfo
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SiteReference import SiteReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SynchronousReplicaPromoteApiResponse import SynchronousReplicaPromoteApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.SynchronousReplicationRole import SynchronousReplicationRole
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.UpdateConsistencyGroupApiResponse import UpdateConsistencyGroupApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponse import UpdateRecoveryPointExpirationTimeApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPoint import VmRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VmRecoveryPointRestoreOverride import VmRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupOverrideSpec import VolumeGroupOverrideSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPoint import VolumeGroupRecoveryPoint
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupRecoveryPointRestoreOverride import VolumeGroupRecoveryPointRestoreOverride
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.VolumeGroupSyncContext import VolumeGroupSyncContext
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.Witness import Witness
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.WitnessAvailabilityStatus import WitnessAvailabilityStatus
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.BaseRecoveryPointSpec import BaseRecoveryPointSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedRegion import ChangedRegion
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedVmRegionsApiResponse import ChangedVmRegionsApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedVolumeGroupRegionsApiResponse import ChangedVolumeGroupRegionsApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ClusterDiscoverOperation import ClusterDiscoverOperation
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ClusterDiscoverSpec import ClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.ComputeChangedRegionsClusterDiscoverSpec import ComputeChangedRegionsClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.DiskRecoveryPointReference import DiskRecoveryPointReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.GetVssMetadataApiResponse import GetVssMetadataApiResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.GetVssMetadataClusterDiscoverSpec import GetVssMetadataClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.RegionType import RegionType
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmDiskRecoveryPointClusterDiscoverSpec import VmDiskRecoveryPointClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmDiskRecoveryPointReference import VmDiskRecoveryPointReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmRecoveryPointChangedRegionsComputeSpec import VmRecoveryPointChangedRegionsComputeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VolumeGroupDiskRecoveryPointClusterDiscoverSpec import VolumeGroupDiskRecoveryPointClusterDiscoverSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VolumeGroupDiskRecoveryPointReference import VolumeGroupDiskRecoveryPointReference
from ntnx_dataprotection_py_client.models.dataprotection.v4.content.VolumeGroupRecoveryPointChangedRegionsComputeSpec import VolumeGroupRecoveryPointChangedRegionsComputeSpec
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.AppMessage import AppMessage
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.ErrorResponse import ErrorResponse
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationError import SchemaValidationError
from ntnx_dataprotection_py_client.models.dataprotection.v4.error.SchemaValidationErrorMessage import SchemaValidationErrorMessage
from ntnx_dataprotection_py_client.models.prism.v4.config.TaskReference import TaskReference
from ntnx_dataprotection_py_client.api_response import ApiResponse



# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ntnx_dataprotection_py_client.api_client import ApiClient


class RecoveryPointsApi(object):
    """IGNORE:
    NOTE: A placeholder for class level description
    IGNORE
    """  # noqa: E501

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()

        self.api_client = api_client
        self.__headers_to_skip = { 'authorization', 'cookie', 'host', 'user-agent' }

    def create_recovery_point(self, body, **kwargs):  # noqa: E501
        """Create a recovery point

        >>> response = api.create_recovery_point(body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.create_recovery_point(body, async_req=True)
        >>> result = thread.get()

        :param body: Details of the request body to create a recovery point.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPoint`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.CreateRecoveryPointApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_recovery_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.CreateRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.CreateRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def delete_recovery_point_by_id(self, extId, **kwargs):  # noqa: E501
        """Delete a recovery point

        >>> response = api.delete_recovery_point_by_id(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.delete_recovery_point_by_id(extId, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.DeleteRecoveryPointApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `delete_recovery_point_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}', 'DELETE',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.DeleteRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}', 'DELETE',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.DeleteRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def discover_cluster_for_recovery_point_id(self, extId, body, **kwargs):  # noqa: E501
        """Discover cluster info for a recovery point

        >>> response = api.discover_cluster_for_recovery_point_id(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.discover_cluster_for_recovery_point_id(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type extId:
            :class:`str`, required
        :param body: Request body for discover cluster api containing recovery point details.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.content.ClusterDiscoverSpec`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ClusterInfoApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `discover_cluster_for_recovery_point_id`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `discover_cluster_for_recovery_point_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/discover-cluster', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ClusterInfoApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/discover-cluster', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ClusterInfoApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def get_recovery_point_by_id(self, extId, **kwargs):  # noqa: E501
        """Get a recovery point

        >>> response = api.get_recovery_point_by_id(extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_recovery_point_by_id(extId, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetRecoveryPointApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `get_recovery_point_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.GetRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.GetRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def get_vm_recovery_point_by_id(self, recoveryPointExtId, extId, **kwargs):  # noqa: E501
        """Get a VM recovery point

        >>> response = api.get_vm_recovery_point_by_id(recoveryPointExtId, extId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_vm_recovery_point_by_id(recoveryPointExtId, extId, async_req=True)
        >>> result = thread.get()

        :param recoveryPointExtId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type recoveryPointExtId:
            :class:`str`, required
        :param extId: The external identifier that can be used to identify a VM recovery point.
        :type extId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.GetVmRecoveryPointApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'recoveryPointExtId' is set
        if ('recoveryPointExtId' not in params or params['recoveryPointExtId'] is None):
            raise ValueError("Missing the required parameter `recoveryPointExtId` when calling `get_vm_recovery_point_by_id`")  # noqa: E501
        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `get_vm_recovery_point_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'recoveryPointExtId' in params and params['recoveryPointExtId'] is not None:
            path_params['recoveryPointExtId'] = params['recoveryPointExtId']  # noqa: E501
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['recoveryPointExtId', 'extId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{recoveryPointExtId}/vm-recovery-points/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.GetVmRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{recoveryPointExtId}/vm-recovery-points/{extId}', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.GetVmRecoveryPointApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def get_vss_metadata_by_vm_recovery_point_id(self, recoveryPointExtId, vmRecoveryPointExtId, **kwargs):  # noqa: E501
        """Get VSS metadata by VM recovery point ID

        >>> response = api.get_vss_metadata_by_vm_recovery_point_id(recoveryPointExtId, vmRecoveryPointExtId)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.get_vss_metadata_by_vm_recovery_point_id(recoveryPointExtId, vmRecoveryPointExtId, async_req=True)
        >>> result = thread.get()

        :param recoveryPointExtId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type recoveryPointExtId:
            :class:`str`, required
        :param vmRecoveryPointExtId: The external identifier that can be used to identify a VM recovery point.
        :type vmRecoveryPointExtId:
            :class:`str`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.content.GetVssMetadataApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'recoveryPointExtId' is set
        if ('recoveryPointExtId' not in params or params['recoveryPointExtId'] is None):
            raise ValueError("Missing the required parameter `recoveryPointExtId` when calling `get_vss_metadata_by_vm_recovery_point_id`")  # noqa: E501
        # verify the required parameter 'vmRecoveryPointExtId' is set
        if ('vmRecoveryPointExtId' not in params or params['vmRecoveryPointExtId'] is None):
            raise ValueError("Missing the required parameter `vmRecoveryPointExtId` when calling `get_vss_metadata_by_vm_recovery_point_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'recoveryPointExtId' in params and params['recoveryPointExtId'] is not None:
            path_params['recoveryPointExtId'] = params['recoveryPointExtId']  # noqa: E501
        if 'vmRecoveryPointExtId' in params and params['vmRecoveryPointExtId'] is not None:
            path_params['vmRecoveryPointExtId'] = params['vmRecoveryPointExtId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/octet-stream', 'application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['recoveryPointExtId', 'vmRecoveryPointExtId'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/content/recovery-points/{recoveryPointExtId}/vm-recovery-points/{vmRecoveryPointExtId}/vss-metadata', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.content.GetVssMetadataApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/content/recovery-points/{recoveryPointExtId}/vm-recovery-points/{vmRecoveryPointExtId}/vss-metadata', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.content.GetVssMetadataApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def list_recovery_points(self, X_Cluster_Id=None, _page=None, _limit=None, _filter=None, _orderby=None, _select=None, **kwargs):  # noqa: E501
        """List recovery points

        >>> response = api.list_recovery_points((optional) X_Cluster_Id, (optional) _page, (optional) _limit, (optional) _filter, (optional) _orderby, (optional) _select)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.list_recovery_points(async_req=True)
        >>> result = thread.get()

        :param X_Cluster_Id: Cluster type from which recovery points must be fetched. Valid values: [AOS, MST]
        :type X_Cluster_Id:
            :class:`str`
        :param _page: A URL query parameter that specifies the page number of the result set. It must be a positive integer between 0 and the maximum number of pages that are available for that resource. Any number out of this range might lead to no results. 
        :type _page:
            :class:`int`
        :param _limit: A URL query parameter that specifies the total number of records returned in the result set.  Must be a positive integer between 1 and 100. Any number out of this range will lead to a validation error. If the limit is not provided, a default value of 50 records will be returned in the result set. 
        :type _limit:
            :class:`int`
        :param _filter: A URL query parameter that allows clients to filter a collection of resources. The expression specified with $filter is evaluated for each resource in the collection, and only items where the expression evaluates to true are included in the response. Expression specified with the $filter must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. For example, filter '$filter=name eq 'karbon-ntnx-1.0' would filter the result on cluster name 'karbon-ntnx1.0', filter '$filter=startswith(name, 'C')' would filter on cluster name starting with 'C'. The filter can be applied to the following fields: - creationTime - extId - locationAgnosticId - name - ownerExtId - recoveryPointType - vmRecoveryPoints - volumeGroupRecoveryPoints 
        :type _filter:
            :class:`str`
        :param _orderby: A URL query parameter that allows clients to specify the sort criteria for the returned list of objects. Resources can be sorted in ascending order using asc or descending order using desc. If asc or desc are not specified, the resources will be sorted in ascending order by default. For example, '$orderby=templateName desc' would get all templates sorted by templateName in descending order. The orderby can be applied to the following fields: - creationTime - expirationTime - name - ownerExtId 
        :type _orderby:
            :class:`str`
        :param _select: A URL query parameter that allows clients to request a specific set of properties for each entity or complex type. Expression specified with the $select must conform to the [OData V4.01](https://docs.oasis-open.org/odata/odata/v4.01/odata-v4.01-part1-protocol.html) URL conventions. If a $select expression consists of a single select item that is an asterisk (i.e., *), then all properties on the matching resource will be returned. - creationTime - expirationTime - extId - name - recoveryPointType 
        :type _select:
            :class:`str`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ListRecoveryPointsApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']


        collection_formats = {}

        path_params = {}

        query_params = []
        if '_page' in params and params['_page'] is not None:
            query_params.append(('$page', params['_page']))  # noqa: E501
        if '_limit' in params and params['_limit'] is not None:
            query_params.append(('$limit', params['_limit']))  # noqa: E501
        if '_filter' in params and params['_filter'] is not None:
            query_params.append(('$filter', params['_filter']))  # noqa: E501
        if '_orderby' in params and params['_orderby'] is not None:
            query_params.append(('$orderby', params['_orderby']))  # noqa: E501
        if '_select' in params and params['_select'] is not None:
            query_params.append(('$select', params['_select']))  # noqa: E501

        header_params = {}
        if 'X_Cluster_Id' in params and params['X_Cluster_Id'] is not None:
            header_params['X-Cluster-Id'] = params['X_Cluster_Id']  # noqa: E501
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['X_Cluster_Id', '_page', '_limit', '_filter', '_orderby', '_select'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ListRecoveryPointsApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points', 'GET',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.ListRecoveryPointsApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def replicate_recovery_point(self, extId, body, **kwargs):  # noqa: E501
        """Replicate a recovery point

        >>> response = api.replicate_recovery_point(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.replicate_recovery_point(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type extId:
            :class:`str`, required
        :param body: External identifier of the cluster and the Prism Central where the recovery point is to be replicated. The recovery point identified by `extId` is replicated from the current Prism Central to the remote Prism Central with the external identifier `pcExtId` . This replication allows the data-protection service to decide on which cluster to perform the automatic replication. However, the user also has the option to choose the cluster identified by `clusterExtId` to which the recovery point identified by `extId` should be replicated. Cross-AZ replication can be performed only by users having legacy roles (e.g. `admin`).
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicationSpec`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointReplicateApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `replicate_recovery_point`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `replicate_recovery_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/replicate', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.RecoveryPointReplicateApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/replicate', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.RecoveryPointReplicateApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def restore_recovery_point(self, extId, body=None, **kwargs):  # noqa: E501
        """Restore recovery point

        >>> response = api.restore_recovery_point(extId, (optional) body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.restore_recovery_point(extId, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type extId:
            :class:`str`, required
        :param body: Specification for the restore action on the top-level recovery point. For a recovery point that contains multiple VM or volume group recovery points, users can selectively trigger restore for any specific set of VM or volume group recovery point(s). In case no particular selection is made, all VM and volume group recovery points that are a part of the top-level recovery point will be restored.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestorationSpec`
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.RecoveryPointRestoreApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `restore_recovery_point`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/restore', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.RecoveryPointRestoreApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/restore', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.RecoveryPointRestoreApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def set_recovery_point_expiration_time(self, extId, body, **kwargs):  # noqa: E501
        """Set the expiration time of the recovery point

        >>> response = api.set_recovery_point_expiration_time(extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.set_recovery_point_expiration_time(extId, body, async_req=True)
        >>> result = thread.get()

        :param extId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type extId:
            :class:`str`, required
        :param body: Request body details to set the expiration time for the recovery point.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ExpirationTimeSpec`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `set_recovery_point_expiration_time`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `set_recovery_point_expiration_time`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/set-expiration-time', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/config/recovery-points/{extId}/$actions/set-expiration-time', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.config.UpdateRecoveryPointExpirationTimeApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def vm_recovery_point_compute_changed_regions(self, recoveryPointExtId, vmRecoveryPointExtId, extId, body, **kwargs):  # noqa: E501
        """Compute VM recovery points changed regions

        >>> response = api.vm_recovery_point_compute_changed_regions(recoveryPointExtId, vmRecoveryPointExtId, extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.vm_recovery_point_compute_changed_regions(recoveryPointExtId, vmRecoveryPointExtId, extId, body, async_req=True)
        >>> result = thread.get()

        :param recoveryPointExtId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type recoveryPointExtId:
            :class:`str`, required
        :param vmRecoveryPointExtId: The external identifier that can be used to identify a VM recovery point.
        :type vmRecoveryPointExtId:
            :class:`str`, required
        :param extId: Disk recovery point identifier.
        :type extId:
            :class:`str`, required
        :param body: Compute changed region parameters. These parameters allow you to specify a start offset, length, block size, and a reference disk recovery point. All parameters are optional. However, if you need to set a reference disk recovery point, you must specify all three parameters: recovery point ID, VM recovery point ID, and disk recovery point ID.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.content.VmRecoveryPointChangedRegionsComputeSpec`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedVmRegionsApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'recoveryPointExtId' is set
        if ('recoveryPointExtId' not in params or params['recoveryPointExtId'] is None):
            raise ValueError("Missing the required parameter `recoveryPointExtId` when calling `vm_recovery_point_compute_changed_regions`")  # noqa: E501
        # verify the required parameter 'vmRecoveryPointExtId' is set
        if ('vmRecoveryPointExtId' not in params or params['vmRecoveryPointExtId'] is None):
            raise ValueError("Missing the required parameter `vmRecoveryPointExtId` when calling `vm_recovery_point_compute_changed_regions`")  # noqa: E501
        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `vm_recovery_point_compute_changed_regions`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `vm_recovery_point_compute_changed_regions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'recoveryPointExtId' in params and params['recoveryPointExtId'] is not None:
            path_params['recoveryPointExtId'] = params['recoveryPointExtId']  # noqa: E501
        if 'vmRecoveryPointExtId' in params and params['vmRecoveryPointExtId'] is not None:
            path_params['vmRecoveryPointExtId'] = params['vmRecoveryPointExtId']  # noqa: E501
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['recoveryPointExtId', 'vmRecoveryPointExtId', 'extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/content/recovery-points/{recoveryPointExtId}/vm-recovery-points/{vmRecoveryPointExtId}/disk-recovery-points/{extId}/$actions/compute-changed-regions', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.content.ChangedVmRegionsApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/content/recovery-points/{recoveryPointExtId}/vm-recovery-points/{vmRecoveryPointExtId}/disk-recovery-points/{extId}/$actions/compute-changed-regions', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.content.ChangedVmRegionsApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass

    def volume_group_recovery_point_compute_changed_regions(self, recoveryPointExtId, volumeGroupRecoveryPointExtId, extId, body, **kwargs):  # noqa: E501
        """Compute Volume Group recovery points changed regions

        >>> response = api.volume_group_recovery_point_compute_changed_regions(recoveryPointExtId, volumeGroupRecoveryPointExtId, extId, body)

        This method makes a synchronous HTTP request by default. To make an asynchronous HTTP request, please pass async_req=True.

        >>> thread = api.volume_group_recovery_point_compute_changed_regions(recoveryPointExtId, volumeGroupRecoveryPointExtId, extId, body, async_req=True)
        >>> result = thread.get()

        :param recoveryPointExtId: The external identifier that can be used to retrieve the recovery point using its URL.
        :type recoveryPointExtId:
            :class:`str`, required
        :param volumeGroupRecoveryPointExtId: External identifier of the volume group recovery point.
        :type volumeGroupRecoveryPointExtId:
            :class:`str`, required
        :param extId: Disk recovery point identifier.
        :type extId:
            :class:`str`, required
        :param body: Compute changed region parameters. These parameters allow you to specify a start offset, length, block size, and a reference disk recovery point. All parameters are optional. However, if you need to set a reference disk recovery point, you must specify all three parameters: recovery point ID, volume group recovery point ID, and disk recovery point ID.
        :type body:
            :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.content.VolumeGroupRecoveryPointChangedRegionsComputeSpec`, required
        :param kwargs: kwargs for the method.
                       The following can be passed for an asynchronous HTTP call::

                           async_req=True
        :return: An instance of class :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.content.ChangedVolumeGroupRegionsApiResponse`.

                 If the method is called asynchronously, returns the request thread.
        """ # noqa: E501
        kwargs['_return_http_data_only'] = True

        params = dict(locals())
        for key, val in six.iteritems(params['kwargs']):
            params[key] = val
        del params['kwargs']
        del params['self']

        # verify the required parameter 'recoveryPointExtId' is set
        if ('recoveryPointExtId' not in params or params['recoveryPointExtId'] is None):
            raise ValueError("Missing the required parameter `recoveryPointExtId` when calling `volume_group_recovery_point_compute_changed_regions`")  # noqa: E501
        # verify the required parameter 'volumeGroupRecoveryPointExtId' is set
        if ('volumeGroupRecoveryPointExtId' not in params or params['volumeGroupRecoveryPointExtId'] is None):
            raise ValueError("Missing the required parameter `volumeGroupRecoveryPointExtId` when calling `volume_group_recovery_point_compute_changed_regions`")  # noqa: E501
        # verify the required parameter 'extId' is set
        if ('extId' not in params or params['extId'] is None):
            raise ValueError("Missing the required parameter `extId` when calling `volume_group_recovery_point_compute_changed_regions`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `volume_group_recovery_point_compute_changed_regions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'recoveryPointExtId' in params and params['recoveryPointExtId'] is not None:
            path_params['recoveryPointExtId'] = params['recoveryPointExtId']  # noqa: E501
        if 'volumeGroupRecoveryPointExtId' in params and params['volumeGroupRecoveryPointExtId'] is not None:
            path_params['volumeGroupRecoveryPointExtId'] = params['volumeGroupRecoveryPointExtId']  # noqa: E501
        if 'extId' in params and params['extId'] is not None:
            path_params['extId'] = params['extId']  # noqa: E501

        query_params = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client._select_header_accept(
            ['application/json'])  # noqa: E501
        if 'Accept' in params and params.get('Accept') is not None:
            header_params['Accept'] = params.get('Accept')

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client._select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501
        if 'Content-Type' in params and params.get('Content-Type') is not None:
            header_params['Content-Type'] = params.get('Content-Type')

        # Process operation specific headers
        extra_params = []
        extra_params.append('async_req')
        extra_params.append('_return_http_data_only')
        extra_params.append('_preload_content')
        extra_params.append('_request_timeout')
        all_params = set(['recoveryPointExtId', 'volumeGroupRecoveryPointExtId', 'extId', 'body'])
        all_params.update(extra_params)
        for key, val in six.iteritems(params):
            if val is not None and key.lower() not in self.__headers_to_skip and key not in all_params:
                if key.lower() == 'if_match'.lower():
                    key = 'If-Match'
                elif key.lower() == 'if_none_match'.lower():
                    key = 'If-None-Match'
                header_params[key] = val

        form_params = []
        local_var_files = {}

        # Authentication setting
        auth_settings = ['apiKeyAuthScheme', 'basicAuthScheme']  # noqa: E501

        body_params = None
        if 'body' in params and params['body'] is not None:
            body_params = params['body']

        try:
            if kwargs.get('async_req'):
                return self.api_client._call_api(
                    '/api/dataprotection/v4.0/content/recovery-points/{recoveryPointExtId}/volume-group-recovery-points/{volumeGroupRecoveryPointExtId}/disk-recovery-points/{extId}/$actions/compute-changed-regions', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.content.ChangedVolumeGroupRegionsApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
            else:
                (data) = self.api_client._call_api(
                    '/api/dataprotection/v4.0/content/recovery-points/{recoveryPointExtId}/volume-group-recovery-points/{volumeGroupRecoveryPointExtId}/disk-recovery-points/{extId}/$actions/compute-changed-regions', 'POST',
                    path_params,
                    query_params,
                    header_params,
                    body=body_params,
                    post_params=form_params,
                    files=local_var_files,
                    response_type='dataprotection.v4.content.ChangedVolumeGroupRegionsApiResponse',  # noqa: E501
                    auth_settings=auth_settings,
                    async_req=params.get('async_req'),
                    _return_http_data_only=params.get('_return_http_data_only'),
                    _preload_content=params.get('_preload_content', True),
                    _request_timeout=params.get('_request_timeout'),
                    collection_formats=collection_formats)
                return data
        finally:
            pass



# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import urllib3
from urllib3.connectionpool import HTTPConnectionPool
from urllib3.connectionpool import HTTPSConnectionPool

class CustomPoolManager(urllib3.PoolManager):
    def __init__(self, *args, **kwargs):
        super().__init__(
            num_pools=args[0],
            maxsize=args[1],
            cert_reqs=args[2],
            ca_certs=args[3],
            cert_file=args[4],
            key_file=args[5],
            retries = args[6],
            **kwargs
        )

        self.pool_classes_by_scheme = {
            'http': HTTPConnectionPool,
            'https': HTTPSConnectionPool,
        }

    # Override urlopen to make default value of the redirect parameter as False
    def urlopen(self, method, url, redirect=False, **kw):
        return super().urlopen(method, url, redirect, **kw)




# coding: utf-8


"""
IGNORE:
    Nutanix Data Protection APIs

    Business Continuity with full spectrum of Disaster Recovery and Backup solution. Spanning across Single PC, Cross AZ, MultiSite. Configuration of Recovery points, Protection policies, Recovery Plans. Execution and monitoring of back up and recovery orchestrations on OnPrem as well as Cloud.  # noqa: E501

    OpenAPI spec version: 4.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
IGNORE
"""
import pprint
import json
import ast
import re  # noqa: F401

import six
from pathlib import Path
from ntnx_dataprotection_py_client.models.common.v1.response.ApiLink import ApiLink  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.common.v1.response.ExternalizableAbstractModel import ExternalizableAbstractModel  # noqa: F401,E501
from ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember import ConsistencyGroupMember  # noqa: F401,E501

class ConsistencyGroup(ExternalizableAbstractModel):

    """In many scenarios, it is necessary to capture the state of an application as a combined snapshot of the internal states of a related set of entities at a specific point in time. A consistency group is a collection of these entities, where their combined snapshot reflects the state of an application at that particular point in time.

    :param name: (:attr:`name`) Name of the consistency group.
    :type name: required
     max=256 chars
    
    :param owner_ext_id: (:attr:`owner_ext_id`) The external identifier of the user who created this consistency group. This is a read-only field that is inserted into the consistency group entity at the time of the consistency group creation.
    :type owner_ext_id: 
    
    
    :param members: (:attr:`members`) 
    :type members: required
    
    
    :param cluster_ext_id: (:attr:`cluster_ext_id`) The external identifier of the cluster to which the entities in the consistency group are associated.
    :type cluster_ext_id: 
    
    
    :param protection_policy_ext_id: (:attr:`protection_policy_ext_id`) The external identifier of the protection policy that protects the consistency group.
    :type protection_policy_ext_id: 
    
    

    """
    """
    IGNORE:
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    IGNORE
    """  # noqa: E501
    swagger_types = {
        'name': 'str',
        'owner_ext_id': 'str',
        'members': 'list[dataprotection.v4.config.ConsistencyGroupMember]',
        'cluster_ext_id': 'str',
        'protection_policy_ext_id': 'str',
        'ext_id': 'str',
        'links': 'list[common.v1.response.ApiLink]',
        'tenant_id': 'str',
        '_reserved': 'dict(str, object)',
        '_object_type': 'str',
        '_unknown_fields': 'dict(str, object)',
    }

    attribute_map = {
        'name': 'name',
        'owner_ext_id': 'ownerExtId',
        'members': 'members',
        'cluster_ext_id': 'clusterExtId',
        'protection_policy_ext_id': 'protectionPolicyExtId',
        'ext_id': 'extId',
        'links': 'links',
        'tenant_id': 'tenantId',
        '_reserved': '$reserved',
        '_object_type': '$objectType',
        '_unknown_fields': '$unknownFields',
    }



    def __init__(self, name=None, owner_ext_id=None, members=None, cluster_ext_id=None, protection_policy_ext_id=None, ext_id=None, links=None, tenant_id=None, *args, **kwargs):  # noqa: E501
        ExternalizableAbstractModel.__init__(self, ext_id, links, tenant_id, *args, **kwargs)
        self.__name = None
        self.__owner_ext_id = None
        self.__members = None
        self.__cluster_ext_id = None
        self.__protection_policy_ext_id = None
        self.discriminator = None
        self.__name = name
        if owner_ext_id is not None:
            self.__owner_ext_id = owner_ext_id
        self.__members = members
        if cluster_ext_id is not None:
            self.__cluster_ext_id = cluster_ext_id
        if protection_policy_ext_id is not None:
            self.__protection_policy_ext_id = protection_policy_ext_id

    def _initialize_object_type(self):
        return 'dataprotection.v4.config.ConsistencyGroup'

    def _initialize_object_version(self):
        return 'v4.r0'


    @property
    def name(self):
        """
        Name of the consistency group.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__name

    @name.setter
    def name(self, name):
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if name is not None and len(name) > 256:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `256`")  # noqa: E501

        self.__name = name

    @property
    def owner_ext_id(self):
        """
        The external identifier of the user who created this consistency group. This is a read-only field that is inserted into the consistency group entity at the time of the consistency group creation.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__owner_ext_id

    @owner_ext_id.setter
    def owner_ext_id(self, owner_ext_id):
        if owner_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', owner_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `owner_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__owner_ext_id = owner_ext_id

    @property
    def members(self):
        """
        

        :type:
             list[ :class:`~ntnx_dataprotection_py_client.models.dataprotection.v4.config.ConsistencyGroupMember` ]
        """  # noqa: E501
        return self.__members

    @members.setter
    def members(self, members):
        if members is None:
            raise ValueError("Invalid value for `members`, must not be `None`")  # noqa: E501

        self.__members = members

    @property
    def cluster_ext_id(self):
        """
        The external identifier of the cluster to which the entities in the consistency group are associated.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__cluster_ext_id

    @cluster_ext_id.setter
    def cluster_ext_id(self, cluster_ext_id):
        if cluster_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', cluster_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `cluster_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__cluster_ext_id = cluster_ext_id

    @property
    def protection_policy_ext_id(self):
        """
        The external identifier of the protection policy that protects the consistency group.

        :type:
                :class:`~str`
        """  # noqa: E501
        return self.__protection_policy_ext_id

    @protection_policy_ext_id.setter
    def protection_policy_ext_id(self, protection_policy_ext_id):
        if protection_policy_ext_id is not None and not re.search('^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$', protection_policy_ext_id):  # noqa: E501
            raise ValueError(r"Invalid value for `protection_policy_ext_id`, must be a follow pattern or equal to `/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/`")  # noqa: E501

        self.__protection_policy_ext_id = protection_policy_ext_id

    def _to_dict(self, sanitize):
        """Returns the model properties as a dict. Omits None properties based on the provided "sanitize" parameter.

        :param sanitize: A flag to omit None properties if set to True
        :type sanitize: bool
        """

        result = {}
        for attr, attr_type in six.iteritems(self.swagger_types):

            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x._to_dict(sanitize) if hasattr(x, "_to_dict") else x,
                    value
                ))
            elif hasattr(value, "_to_dict"):
                result[attr] = value._to_dict(sanitize)
            elif isinstance(value, Path):
                result[attr] = str(value)
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1]._to_dict(sanitize)) if hasattr(item[1], "_to_dict")
                    else (
                        (item[0], str(item[1])) if item[0] == 'path' and '$objectType' in value and value['$objectType'] == 'pathlib.Path'
                        else item
                    ),
                    six.iteritems(value)
                ))
            else:
                if sanitize:
                    if value is not None:
                        result[attr] = value
                else:
                    result[attr] = value
        if issubclass(ConsistencyGroup, dict):
            for key, value in six.iteritems(self):
                result[key] = value

        return result

    def to_dict(self):
        """Returns the model properties as a dictionary"""
        return self._to_dict(False)

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self._to_dict(True))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConsistencyGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

